==> firefox-esr_102.14.0esr.orig.tar.xz: firefox-102.14.0/toolkit/mozapps/extensions/test/xpinstall/browser_auth2.js <==
// ----------------------------------------------------------------------------
// Test whether an install fails when authentication is required and bad
// credentials are given
// This verifies bug 312473
function test() {
  // This test depends on InstallTrigger.install availability.
  setInstallTriggerPrefs();

  // Turn off the authentication dialog blocking for this test.
  Services.prefs.setBoolPref(
    "network.auth.non-web-content-triggered-resources-http-auth-allow",
    true
  );

  requestLongerTimeout(2);
  Harness.authenticationCallback = get_auth_info;
  Harness.downloadFailedCallback = download_failed;
  Harness.installEndedCallback = install_ended;
  Harness.installsCompletedCallback = finish_test;
  Harness.setup();

  PermissionTestUtils.add(
    "http://example.com/",
    "install",
    Services.perms.ALLOW_ACTION
  );

  var triggers = encodeURIComponent(
    JSON.stringify({
      "Unsigned XPI":
        TESTROOT + "authRedirect.sjs?" + TESTROOT + "amosigned.xpi",
    })
  );
  gBrowser.selectedTab = BrowserTestUtils.addTab(gBrowser);
  BrowserTestUtils.loadURI(
    gBrowser,
    TESTROOT + "installtrigger.html?" + triggers
  );
}

function get_auth_info() {
  return ["baduser", "badpass"];
}

function download_failed(install) {
  is(
    install.error,
    AddonManager.ERROR_NETWORK_FAILURE,
    "Install should have failed"
  );
}

function install_ended(install, addon) {
  ok(false, "Add-on should not have installed");
  return addon.uninstall();
}

function finish_test(count) {
  is(count, 0, "No add-ons should have been installed");
  var authMgr = Cc["@mozilla.org/network/http-auth-manager;1"].getService(
    Ci.nsIHttpAuthManager
  );
  authMgr.clearAll();

  PermissionTestUtils.remove("http://example.com", "install");

  Services.prefs.clearUserPref(
    "network.auth.non-web-content-triggered-resources-http-auth-allow"
  );

  gBrowser.removeCurrentTab();
  Harness.finish();
}

==> firefox-esr_140.3.1esr.orig.tar.xz: firefox-140.3.1/toolkit/mozapps/extensions/test/xpinstall/browser_auth2.js <==
// ----------------------------------------------------------------------------
// Test whether an install fails when authentication is required and bad
// credentials are given
// This verifies bug 312473
function test() {
  // This test depends on InstallTrigger.install availability.
  setInstallTriggerPrefs();

  // Turn off the authentication dialog blocking for this test.
  Services.prefs.setBoolPref(
    "network.auth.non-web-content-triggered-resources-http-auth-allow",
    true
  );

  requestLongerTimeout(2);
  Harness.authenticationCallback = get_auth_info;
  Harness.downloadFailedCallback = download_failed;
  Harness.installEndedCallback = install_ended;
  Harness.installsCompletedCallback = finish_test;
  Harness.setup();

  PermissionTestUtils.add(
    "http://example.com/",
    "install",
    Services.perms.ALLOW_ACTION
  );

  var triggers = encodeURIComponent(
    JSON.stringify({
      "Unsigned XPI":
        TESTROOT + "authRedirect.sjs?" + TESTROOT + "amosigned.xpi",
    })
  );
  gBrowser.selectedTab = BrowserTestUtils.addTab(gBrowser);
  BrowserTestUtils.startLoadingURIString(
    gBrowser,
    TESTROOT + "installtrigger.html?" + triggers
  );
}

function get_auth_info() {
  return ["baduser", "badpass"];
}

function download_failed(install) {
  is(
    install.error,
    AddonManager.ERROR_NETWORK_FAILURE,
    "Install should have failed"
  );
}

function install_ended(install, addon) {
  ok(false, "Add-on should not have installed");
  return addon.uninstall();
}

function finish_test(count) {
  is(count, 0, "No add-ons should have been installed");
  var authMgr = Cc["@mozilla.org/network/http-auth-manager;1"].getService(
    Ci.nsIHttpAuthManager
  );
  authMgr.clearAll();

  PermissionTestUtils.remove("http://example.com", "install");

  Services.prefs.clearUserPref(
    "network.auth.non-web-content-triggered-resources-http-auth-allow"
  );

  gBrowser.removeCurrentTab();
  Harness.finish();
}
